# Classic text adventure games for TRS80 and CoCo

These games are the original ROMs played through an emulator for their
original platforms. They play on your computer's command line.

# Install

```
pip3 install trs80tag
Windows: py -m pip install trs80tag
```

# Play

See the list of games and options:

```
python3 -m trs80tag
Windows: py -m trs80tag
```

For example, to play RaakaTu for the CoCo:

```
python3 -m trs80tag coco_raaka_tu
Windows: py -m trs80tag coco_raaka_tu
```

# Instructions and Info

Complete instructions on these old games can be found on Sean Murphgy's awesome site: [figmentfly.com](figmentfly.com)

# See the code

Disassembly of the ROMS on my site: [computerarcheology.com](computerarcheology.com)

# List of Games

Many more coming soon.

## coco_raaka_tu
Raaka-Tu - 1982 for the TRS-80 Color Computer
  - Everything you need to know: [http://www.figmentfly.com/raakatu/raakatu.html](http://www.figmentfly.com/raakatu/raakatu.html)
  - See the disassembly: [http://computerarcheology.com/CoCo/RaakaTu/](http://computerarcheology.com/CoCo/RaakaTu/)
